**********
Change Log
**********

v{{ cookiecutter.version }} ({% now 'local' %})
===============================================

This package was created with package `et-micc2 <https://github.com/etijskens/et-micc2>`_,
